CountdownController class

Controller for CountDownTimer

Constructors

CountdownController({bool autoStart = false})
Constructor

Properties

autoStart → bool
Whether or not the timer should automatically begin.
final
hashCode → int
The hash code for this object.
no setterinherited
isCompleted ↔ bool?
Checks if the timer is running and enables you to take actions according to that. if the timer is still active,
getter/setter pair
onPause ↔ VoidCallback?
Called when pausing the timer.
getter/setter pair
onRestart ↔ VoidCallback?
Called when restarting the timer.
getter/setter pair
onResume ↔ VoidCallback?
Called when resuming the timer.
getter/setter pair
onSkipNext ↔ VoidCallback?
Called when skipping to the next interval.
getter/setter pair
onSkipPrevious ↔ VoidCallback?
Called when skipping to the previous interval.
getter/setter pair
onStart ↔ VoidCallback?
Called when the timer starts.
getter/setter pair
onStop ↔ VoidCallback?
Called when the timer stops.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<void>
Set timer pause.
restart() → void
Restart timer, starts things fresh.
resume() → void
Resume from pause.
setOnPause(VoidCallback onPause) → void
Set onPause callback.
setOnRestart(VoidCallback onRestart) → void
set onRestart callback.
setOnResume(VoidCallback onResume) → void
Set onResume callback.
setOnSkipNext(VoidCallback onSkipNext) → void
Set onSkipNext callback.
setOnSkipPrevious(VoidCallback onSkipPrevious) → void
Set onSkipPrevious callback.
setOnStart(VoidCallback onStart) → void
Set onStart callback.
setOnStop(VoidCallback onStop) → void
Set onStop callback.
skipNext() → void
Skip to the next interval.
skipPrevious() → void
Skip to the previous interval.
start() → void
Run timer
stop() → void
Stop timer
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited