TimerState class

Constructors

TimerState(bool paused, String status, int currentInterval, int currentMicroSeconds, int intervalMicroSeconds, double volume, bool changeVolume)
TimerState.empty()
TimerState.fromMap(Map<String, dynamic> map)
factory

Properties

changeVolume ↔ bool
getter/setter pair
currentInterval ↔ int
getter/setter pair
currentMicroSeconds ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intervalMicroSeconds ↔ int
getter/setter pair
paused ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String
getter/setter pair
volume ↔ double
getter/setter pair

Methods

advanceToNextInterval(List<IntervalType> intervals) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset(List<IntervalType> intervals) → void
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited