DatabaseManager class

Constructors

DatabaseManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearDatabaseIfNotEmpty() → Future<void>
deleteInterval(String id) → Future<void>
deleteIntervalsByWorkoutId(String workoutId) → Future<void>
getIntervals() → Future<List<IntervalType>>
insertInterval(IntervalType interval) → Future<void>
insertIntervals(List<IntervalType> intervals) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openIntervalDatabase() → Future<Database>
toString() → String
A string representation of this object.
inherited
updateInterval(IntervalType interval) → Future<void>
updateIntervals(List<IntervalType> intervals) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited